from __future__ import annotations

import datasets
import numpy as np

from mteb.abstasks.TaskMetadata import TaskMetadata

from ....abstasks import AbsTaskClustering, MultilingualTask

_LANGUAGES = {
    "amh": ["amh-Ethi"],
    "eng": ["eng-Latn"],
    "fra": ["fra-Latn"],
    "hau": ["hau-Latn"],
    "ibo": ["ibo-Latn"],
    "lin": ["lin-Latn"],
    "lug": ["lug-Latn"],
    "orm": ["orm-Ethi"],
    "pcm": ["pcm-Latn"],
    "run": ["run-Latn"],
    "sna": ["sna-Latn"],
    "som": ["som-Latn"],
    "swa": ["swa-Latn"],
    "tir": ["tir-Ethi"],
    "xho": ["xho-Latn"],
    "yor": ["yor-Latn"],
}


class MasakhaNEWSClusteringS2S(AbsTaskClustering, MultilingualTask):
    metadata = TaskMetadata(
        name="MasakhaNEWSClusteringS2S",
        dataset={
            "path": "masakhane/masakhanews",
            "revision": "8ccc72e69e65f40c70e117d8b3c08306bb788b60",
            "trust_remote_code": True,
        },
        description=(
            "Clustering of news article headlines from MasakhaNEWS dataset. Clustering of 10 sets on the news article label."
        ),
        reference="https://huggingface.co/datasets/masakhane/masakhanews",
        type="Clustering",
        category="s2s",
        eval_splits=["test"],
        eval_langs=_LANGUAGES,
        main_score="v_measure",
        date=None,
        form=None,
        domains=None,
        task_subtypes=None,
        license=None,
        socioeconomic_status=None,
        annotations_creators=None,
        dialect=None,
        text_creation=None,
        bibtex_citation="""@article{Adelani2023MasakhaNEWS,
  title={MasakhaNEWS: News Topic Classification for African languages},
  author={David Ifeoluwa Adelani and  Marek Masiak and  Israel Abebe Azime and  Jesujoba Oluwadara Alabi and  Atnafu Lambebo Tonja and  Christine Mwase and  Odunayo Ogundepo and  Bonaventure F. P. Dossou and  Akintunde Oladipo and  Doreen Nixdorf and  Chris Chinenye Emezue and  Sana Sabah al-azzawi and  Blessing K. Sibanda and  Davis David and  Lolwethu Ndolela and  Jonathan Mukiibi and  Tunde Oluwaseyi Ajayi and  Tatiana Moteu Ngoli and  Brian Odhiambo and  Abraham Toluwase Owodunni and  Nnaemeka C. Obiefuna and  Shamsuddeen Hassan Muhammad and  Saheed Salahudeen Abdullahi and  Mesay Gemeda Yigezu and  Tajuddeen Gwadabe and  Idris Abdulmumin and  Mahlet Taye Bame and  Oluwabusayo Olufunke Awoyomi and  Iyanuoluwa Shode and  Tolulope Anu Adelani and  Habiba Abdulganiy Kailani and  Abdul-Hakeem Omotayo and  Adetola Adeeko and  Afolabi Abeeb and  Anuoluwapo Aremu and  Olanrewaju Samuel and  Clemencia Siro and  Wangari Kimotho and  Onyekachi Raphael Ogbu and  Chinedu E. Mbonu and  Chiamaka I. Chukwuneke and  Samuel Fanijo and  Jessica Ojo and  Oyinkansola F. Awosan and  Tadesse Kebede Guge and  Sakayo Toadoum Sari and  Pamela Nyatsine and  Freedmore Sidume and  Oreen Yousuf and  Mardiyyah Oduwole and  Ussen Kimanuka and  Kanda Patrick Tshinu and  Thina Diko and  Siyanda Nxakama and   Abdulmejid Tuni Johar and  Sinodos Gebre and  Muhidin Mohamed and  Shafie Abdi Mohamed and  Fuad Mire Hassan and  Moges Ahmed Mehamed and  Evrard Ngabire and  and Pontus Stenetorp},
  journal={ArXiv},
  year={2023},
  volume={}
}""",
        n_samples=None,
        avg_character_length=None,
    )

    def load_data(self, **kwargs):
        """Load dataset from HuggingFace hub and convert it to the standard format."""
        if self.data_loaded:
            return
        self.dataset = {}
        for lang in self.hf_subsets:
            self.dataset[lang] = datasets.load_dataset(
                name=lang,
                **self.metadata_dict["dataset"],
            )
            self.dataset_transform(lang)
        self.data_loaded = True

    def dataset_transform(self, lang):
        """Convert to standard format"""
        self.dataset[lang].pop("train")
        self.dataset[lang].pop("validation")

        self.dataset[lang] = self.dataset[lang].remove_columns(
            ["url", "text", "headline_text"]
        )
        texts = self.dataset[lang]["test"]["headline"]
        labels = self.dataset[lang]["test"]["label"]
        new_format = {
            "sentences": [split.tolist() for split in np.array_split(texts, 5)],
            "labels": [split.tolist() for split in np.array_split(labels, 5)],
        }
        self.dataset[lang]["test"] = datasets.Dataset.from_dict(new_format)



from __future__ import annotations

from mteb.abstasks import AbsTaskClassification
from mteb.abstasks.TaskMetadata import TaskMetadata


class WRIMEClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="WRIMEClassification",
        dataset={
            "path": "shunk031/wrime",
            "revision": "3fb7212c389d7818b8e6179e2cdac762f2e081d9",
            "name": "ver2",
            "trust_remote_code": True,
        },
        description="A dataset of Japanese social network rated for sentiment",
        reference="https://aclanthology.org/2021.naacl-main.169/",
        type="Classification",
        category="s2s",
        eval_splits=["test"],
        eval_langs=["jpn-Jpan"],
        main_score="accuracy",
        date=("2011-06-01", "2020-05-31"),
        form=["written"],
        domains=["Social"],
        task_subtypes=["Sentiment/Hate speech"],
        license="The dataset is available for research purposes only. Redistribution of the dataset is prohibited.",
        socioeconomic_status="high",
        annotations_creators="human-annotated",
        dialect=[],
        text_creation="found",
        bibtex_citation="""@inproceedings{kajiwara-etal-2021-wrime,
    title = "{WRIME}: A New Dataset for Emotional Intensity Estimation with Subjective and Objective Annotations",
    author = "Kajiwara, Tomoyuki  and
      Chu, Chenhui  and
      Takemura, Noriko  and
      Nakashima, Yuta  and
      Nagahara, Hajime",
    editor = "Toutanova, Kristina  and
      Rumshisky, Anna  and
      Zettlemoyer, Luke  and
      Hakkani-Tur, Dilek  and
      Beltagy, Iz  and
      Bethard, Steven  and
      Cotterell, Ryan  and
      Chakraborty, Tanmoy  and
      Zhou, Yichao",
    booktitle = "Proceedings of the 2021 Conference of the North American Chapter of the Association for Computational Linguistics: Human Language Technologies",
    month = jun,
    year = "2021",
    address = "Online",
    publisher = "Association for Computational Linguistics",
    url = "https://aclanthology.org/2021.naacl-main.169",
    doi = "10.18653/v1/2021.naacl-main.169",
    pages = "2095--2104",
    abstract = "We annotate 17,000 SNS posts with both the writer{'}s subjective emotional intensity and the reader{'}s objective one to construct a Japanese emotion analysis dataset. In this study, we explore the difference between the emotional intensity of the writer and that of the readers with this dataset. We found that the reader cannot fully detect the emotions of the writer, especially anger and trust. In addition, experimental results in estimating the emotional intensity show that it is more difficult to estimate the writer{'}s subjective labels than the readers{'}. The large gap between the subjective and objective emotions imply the complexity of the mapping from a post to the subjective emotion intensities, which also leads to a lower performance with machine learning models.",
}""",
        n_samples={"test": 2048},
        avg_character_length={"test": 47.78},
    )

    def dataset_transform(self):
        self.dataset = self.dataset.flatten().select_columns(
            ["sentence", "avg_readers.sentiment"]
        )
        self.dataset = self.dataset.rename_columns(
            {"sentence": "text", "avg_readers.sentiment": "label"}
        )
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["test"]
        )



from __future__ import annotations

from mteb.abstasks.AbsTaskClassification import AbsTaskClassification
from mteb.abstasks.TaskMetadata import TaskMetadata


class BengaliHateSpeechClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="BengaliHateSpeechClassification",
        description="The Bengali Hate Speech Dataset is a Bengali-language dataset of news articles collected from various Bengali media sources and categorized based on the type of hate in the text.",
        reference="https://huggingface.co/datasets/bn_hate_speech",
        dataset={
            "path": "rezacsedu/bn_hate_speech",
            "revision": "99612296bc093f0720cac7d7cbfcb67eecf1ca2f",
        },
        type="Classification",
        category="s2s",
        eval_splits=["train"],
        eval_langs=["ben-Beng"],
        main_score="f1",
        date=("2019-12-01", "2020-04-09"),
        form=["written"],
        dialect=[],
        domains=["News"],
        task_subtypes=["Sentiment/Hate speech"],
        license="MIT",
        socioeconomic_status="mixed",
        annotations_creators="expert-annotated",
        text_creation="found",
        bibtex_citation="""@inproceedings{karim2020BengaliNLP,
    title={Classification Benchmarks for Under-resourced Bengali Language based on Multichannel Convolutional-LSTM Network},
    author={Karim, Md. Rezaul and Chakravarti, Bharathi Raja and P. McCrae, John and Cochez, Michael},
    booktitle={7th IEEE International Conference on Data Science and Advanced Analytics (IEEE DSAA,2020)},
    publisher={IEEE},
    year={2020}
}
""",
        n_samples={"train": 3418},
        avg_character_length={"train": 103.42},
    )

    def dataset_transform(self):
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["train"]
        )



from __future__ import annotations

import datasets

from mteb.abstasks.TaskMetadata import TaskMetadata

from ....abstasks import MultilingualTask
from ....abstasks.AbsTaskRetrieval import AbsTaskRetrieval

_EVAL_SPLIT = "dev"

_LANGUAGES = {
    "ar": ["ara-Arab"],
    "bn": ["ben-Beng"],
    "de": ["deu-Latn"],
    "en": ["eng-Latn"],
    "es": ["spa-Latn"],
    "fa": ["fas-Arab"],
    "fi": ["fin-Latn"],
    "fr": ["fra-Latn"],
    "hi": ["hin-Deva"],
    "id": ["ind-Latn"],
    "ja": ["jpn-Jpan"],
    "ko": ["kor-Kore"],
    "ru": ["rus-Cyrl"],
    "sw": ["swa-Latn"],
    "te": ["tel-Telu"],
    "th": ["tha-Thai"],
    "yo": ["yor-Latn"],
    "zh": ["zho-Hans"],
}


def _load_miracl_data(
    path: str, langs: list, splits: str, cache_dir: str = None, revision: str = None
):
    corpus = {lang: {split: None for split in splits} for lang in langs}
    queries = {lang: {split: None for split in splits} for lang in langs}
    relevant_docs = {lang: {split: None for split in splits} for lang in langs}

    split = _EVAL_SPLIT

    for lang in langs:
        # Load corpus data (Can be several millions for languages)
        corpus_identifier = f"corpus-{lang}"
        corpus_data = datasets.load_dataset(
            path,
            corpus_identifier,
            cache_dir=cache_dir,
            revision=revision,
            trust_remote_code=True,
        )
        corpus[lang][split] = {}
        for row in corpus_data["corpus"]:
            docid = row["docid"]
            doc_title = row["title"]
            doc_text = row["text"]
            corpus[lang][split][docid] = {"title": doc_title, "text": doc_text}

        # Load queries data
        queries_identifier = f"queries-{lang}"
        queries_data = datasets.load_dataset(
            path,
            queries_identifier,
            cache_dir=cache_dir,
            revision=revision,
            trust_remote_code=True,
        )
        queries[lang][split] = {}
        for row in queries_data["queries"]:
            query_id = row["query_id"]
            query_text = row["query"]
            queries[lang][split][query_id] = query_text

        # Load relevant documents data
        qrels_identifier = f"{lang}"
        qrels_data = datasets.load_dataset(
            path,
            qrels_identifier,
            cache_dir=cache_dir,
            revision=revision,
            trust_remote_code=True,
        )
        relevant_docs[lang][split] = {}
        for row in qrels_data[split]:
            query_id = row["query_id"]
            doc_id = row["docid"]
            score = row["score"]
            if query_id not in relevant_docs[lang][split]:
                relevant_docs[lang][split][query_id] = {}
            relevant_docs[lang][split][query_id][doc_id] = score

    corpus = datasets.DatasetDict(corpus)
    queries = datasets.DatasetDict(queries)
    relevant_docs = datasets.DatasetDict(relevant_docs)

    return corpus, queries, relevant_docs


class MIRACLRetrieval(MultilingualTask, AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="MIRACLRetrieval",
        description="MIRACL (Multilingual Information Retrieval Across a Continuum of Languages) is a multilingual retrieval dataset that focuses on search across 18 different languages.",
        reference="http://miracl.ai",
        dataset={
            "path": "miracl/mmteb-miracl",
            "revision": "main",
        },
        type="Retrieval",
        category="s2p",
        eval_splits=[_EVAL_SPLIT],
        eval_langs=_LANGUAGES,
        main_score="ndcg_at_10",
        date=("2022-06-01", "2023-01-30"),
        form=["written"],
        domains=["Encyclopaedic"],
        task_subtypes=[],
        license="CC BY-SA 4.0",
        socioeconomic_status="low",
        annotations_creators="expert-annotated",
        dialect=[],
        text_creation="created",
        bibtex_citation="""@article{10.1162/tacl_a_00595,
    author = {Zhang, Xinyu and Thakur, Nandan and Ogundepo, Odunayo and Kamalloo, Ehsan and Alfonso-Hermelo, David and Li, Xiaoguang and Liu, Qun and Rezagholizadeh, Mehdi and Lin, Jimmy},
    title = "{MIRACL: A Multilingual Retrieval Dataset Covering 18 Diverse Languages}",
    journal = {Transactions of the Association for Computational Linguistics},
    volume = {11},
    pages = {1114-1131},
    year = {2023},
    month = {09},
    abstract = "{MIRACL is a multilingual dataset for ad hoc retrieval across 18 languages that collectively encompass over three billion native speakers around the world. This resource is designed to support monolingual retrieval tasks, where the queries and the corpora are in the same language. In total, we have gathered over 726k high-quality relevance judgments for 78k queries over Wikipedia in these languages, where all annotations have been performed by native speakers hired by our team. MIRACL covers languages that are both typologically close as well as distant from 10 language families and 13 sub-families, associated with varying amounts of publicly available resources. Extensive automatic heuristic verification and manual assessments were performed during the annotation process to control data quality. In total, MIRACL represents an investment of around five person-years of human annotator effort. Our goal is to spur research on improving retrieval across a continuum of languages, thus enhancing information access capabilities for diverse populations around the world, particularly those that have traditionally been underserved. MIRACL is available at http://miracl.ai/.}",
    issn = {2307-387X},
    doi = {10.1162/tacl_a_00595},
    url = {https://doi.org/10.1162/tacl\_a\_00595},
    eprint = {https://direct.mit.edu/tacl/article-pdf/doi/10.1162/tacl\_a\_00595/2157340/tacl\_a\_00595.pdf},
}""",
        n_samples=None,
        avg_character_length={
            "dev": {
                "ar": {
                    "average_document_length": 318.6539598547405,
                    "average_query_length": 29.480662983425415,
                    "num_documents": 2061414,
                    "num_queries": 2896,
                    "average_relevant_docs_per_query": 1.953729281767956,
                },
                "bn": {
                    "average_document_length": 383.2428136511194,
                    "average_query_length": 46.98053527980535,
                    "num_documents": 297265,
                    "num_queries": 411,
                    "average_relevant_docs_per_query": 2.099756690997567,
                },
                "de": {
                    "average_document_length": 414.28004442393404,
                    "average_query_length": 46.0,
                    "num_documents": 15866222,
                    "num_queries": 305,
                    "average_relevant_docs_per_query": 2.6590163934426227,
                },
                "en": {
                    "average_document_length": 401.0042914921588,
                    "average_query_length": 40.247809762202756,
                    "num_documents": 32893221,
                    "num_queries": 799,
                    "average_relevant_docs_per_query": 2.911138923654568,
                },
                "es": {
                    "average_document_length": 403.71153493754986,
                    "average_query_length": 47.373456790123456,
                    "num_documents": 10373953,
                    "num_queries": 648,
                    "average_relevant_docs_per_query": 4.609567901234568,
                },
                "fa": {
                    "average_document_length": 262.6478385010321,
                    "average_query_length": 41.1503164556962,
                    "num_documents": 2207172,
                    "num_queries": 632,
                    "average_relevant_docs_per_query": 2.079113924050633,
                },
                "fi": {
                    "average_document_length": 359.87767671935734,
                    "average_query_length": 38.63493312352478,
                    "num_documents": 1883509,
                    "num_queries": 1271,
                    "average_relevant_docs_per_query": 1.925255704169945,
                },
                "fr": {
                    "average_document_length": 343.6283550271699,
                    "average_query_length": 43.883381924198254,
                    "num_documents": 14636953,
                    "num_queries": 343,
                    "average_relevant_docs_per_query": 2.131195335276968,
                },
                "hi": {
                    "average_document_length": 370.96196845914386,
                    "average_query_length": 53.34,
                    "num_documents": 506264,
                    "num_queries": 350,
                    "average_relevant_docs_per_query": 2.1485714285714286,
                },
                "id": {
                    "average_document_length": 350.2785651811673,
                    "average_query_length": 37.958333333333336,
                    "num_documents": 1446315,
                    "num_queries": 960,
                    "average_relevant_docs_per_query": 3.216666666666667,
                },
                "ja": {
                    "average_document_length": 145.8538220556965,
                    "average_query_length": 17.71395348837209,
                    "num_documents": 6953614,
                    "num_queries": 860,
                    "average_relevant_docs_per_query": 2.0813953488372094,
                },
                "ko": {
                    "average_document_length": 173.97649170809927,
                    "average_query_length": 21.624413145539908,
                    "num_documents": 1486752,
                    "num_queries": 213,
                    "average_relevant_docs_per_query": 2.568075117370892,
                },
                "ru": {
                    "average_document_length": 332.2475377512674,
                    "average_query_length": 44.13258785942492,
                    "num_documents": 9543918,
                    "num_queries": 1252,
                    "average_relevant_docs_per_query": 2.8434504792332267,
                },
                "sw": {
                    "average_document_length": 228.71348655286377,
                    "average_query_length": 38.97095435684647,
                    "num_documents": 131924,
                    "num_queries": 482,
                    "average_relevant_docs_per_query": 1.887966804979253,
                },
                "te": {
                    "average_document_length": 396.2108674545774,
                    "average_query_length": 38.11231884057971,
                    "num_documents": 518079,
                    "num_queries": 828,
                    "average_relevant_docs_per_query": 1.0314009661835748,
                },
                "th": {
                    "average_document_length": 356.8283496198581,
                    "average_query_length": 42.87585266030014,
                    "num_documents": 542166,
                    "num_queries": 733,
                    "average_relevant_docs_per_query": 1.8321964529331514,
                },
                "yo": {
                    "average_document_length": 159.35250698366738,
                    "average_query_length": 37.6890756302521,
                    "num_documents": 49043,
                    "num_queries": 119,
                    "average_relevant_docs_per_query": 1.2100840336134453,
                },
                "zh": {
                    "average_document_length": 119.9458931721347,
                    "average_query_length": 10.867684478371501,
                    "num_documents": 4934368,
                    "num_queries": 393,
                    "average_relevant_docs_per_query": 2.5292620865139948,
                },
            }
        },
    )

    def load_data(self, **kwargs):
        if self.data_loaded:
            return

        self.corpus, self.queries, self.relevant_docs = _load_miracl_data(
            path=self.metadata_dict["dataset"]["path"],
            langs=self.hf_subsets,
            splits=self.metadata_dict["eval_splits"],
            cache_dir=kwargs.get("cache_dir", None),
            revision=self.metadata_dict["dataset"]["revision"],
        )

        self.data_loaded = True



from collections import Counter

import datasets
import numpy as np

from mteb.abstasks.AbsTaskClustering import AbsTaskClustering
from mteb.abstasks.AbsTaskClusteringFast import (
    AbsTaskClusteringFast,
    check_label_distribution,
)
from mteb.abstasks.TaskMetadata import TaskMetadata

NUM_SAMPLES = 2048


class HALClusteringS2S(AbsTaskClustering):
    superseeded_by = "HALClusteringS2S.v2"

    metadata = TaskMetadata(
        name="HALClusteringS2S",
        description="Clustering of titles from HAL (https://huggingface.co/datasets/lyon-nlp/clustering-hal-s2s)",
        reference="https://huggingface.co/datasets/lyon-nlp/clustering-hal-s2s",
        dataset={
            "path": "lyon-nlp/clustering-hal-s2s",
            "revision": "e06ebbbb123f8144bef1a5d18796f3dec9ae2915",
        },
        type="Clustering",
        category="s2s",
        eval_splits=["test"],
        eval_langs=["fra-Latn"],
        main_score="v_measure",
        date=None,
        form=None,
        domains=None,
        task_subtypes=None,
        license=None,
        socioeconomic_status=None,
        annotations_creators=None,
        dialect=None,
        text_creation=None,
        bibtex_citation="""@misc{ciancone2024extending,
      title={Extending the Massive Text Embedding Benchmark to French}, 
      author={Mathieu Ciancone and Imene Kerboua and Marion Schaeffer and Wissam Siblini},
      year={2024},
      eprint={2405.20468},
      archivePrefix={arXiv},
      primaryClass={cs.CL}
}""",
        n_samples=None,
        avg_character_length=None,
    )

    def dataset_transform(self):
        """Convert to standard format"""
        self.dataset = self.dataset.remove_columns("hal_id")
        titles = self.dataset["test"]["title"]
        domains = self.dataset["test"]["domain"]
        new_format = {
            "sentences": [split.tolist() for split in np.array_split(titles, 10)],
            "labels": [split.tolist() for split in np.array_split(domains, 10)],
        }
        self.dataset["test"] = datasets.Dataset.from_dict(new_format)


class HALClusteringS2SFast(AbsTaskClusteringFast):
    max_document_to_embed = NUM_SAMPLES
    max_fraction_of_documents_to_embed = None

    metadata = TaskMetadata(
        name="HALClusteringS2S.v2",
        description="Clustering of titles from HAL (https://huggingface.co/datasets/lyon-nlp/clustering-hal-s2s)",
        reference="https://huggingface.co/datasets/lyon-nlp/clustering-hal-s2s",
        dataset={
            "path": "lyon-nlp/clustering-hal-s2s",
            "revision": "e06ebbbb123f8144bef1a5d18796f3dec9ae2915",
        },
        type="Clustering",
        category="s2s",
        eval_splits=["test"],
        eval_langs=["fra-Latn"],
        main_score="v_measure",
        date=("2000-03-29", "2024-05-24"),
        form=["written"],
        domains=["Academic"],
        task_subtypes=["Thematic clustering"],
        license="Apache-2.0",
        socioeconomic_status="medium",
        annotations_creators="human-annotated",
        dialect=[],
        text_creation="found",
        bibtex_citation="""@misc{ciancone2024extending,
      title={Extending the Massive Text Embedding Benchmark to French}, 
      author={Mathieu Ciancone and Imene Kerboua and Marion Schaeffer and Wissam Siblini},
      year={2024},
      eprint={2405.20468},
      archivePrefix={arXiv},
      primaryClass={cs.CL}
}""",
        n_samples={"test": NUM_SAMPLES},
        avg_character_length={"test": 86.6},
    )

    def dataset_transform(self):
        """Convert to standard format"""
        self.dataset["test"] = self.dataset["test"].remove_columns("hal_id")
        self.dataset["test"] = self.dataset["test"].rename_columns(
            {"title": "sentences", "domain": "labels"}
        )
        labels_count = Counter(self.dataset["test"]["labels"])

        # keep classes with more than 2 samples after stratified_subsampling
        frequent_labels = set(
            label
            for label, count in labels_count.items()
            if count > len(self.dataset["test"]) * 2 / NUM_SAMPLES
        )
        self.dataset["test"] = self.dataset["test"].filter(
            lambda row: row["labels"] in frequent_labels
        )
        self.dataset["test"] = self.dataset["test"].cast(
            datasets.Features(
                sentences=datasets.Value("string"),
                labels=datasets.ClassLabel(names=sorted(list(frequent_labels))),
            )
        )
        for split in self.metadata.eval_splits:
            check_label_distribution(self.dataset[split])

        self.dataset = self.stratified_subsampling(
            self.dataset,
            self.seed,
            self.metadata.eval_splits,
            label="labels",
            n_samples=NUM_SAMPLES,
        )



from __future__ import annotations

from datasets import load_dataset

from mteb.abstasks import AbsTaskRetrieval, MultilingualTask, TaskMetadata

_EVAL_SPLIT = "test"

_LANGUAGES = [
    "acm_Arab",
    "afr_Latn",
    "als_Latn",
    "amh_Ethi",
    "apc_Arab",
    "arb_Arab",
    "arb_Latn",
    "ars_Arab",
    "ary_Arab",
    "arz_Arab",
    "asm_Beng",
    "azj_Latn",
    "bam_Latn",
    "ben_Beng",
    "ben_Latn",
    "bod_Tibt",
    "bul_Cyrl",
    "cat_Latn",
    "ceb_Latn",
    "ces_Latn",
    "ckb_Arab",
    "dan_Latn",
    "deu_Latn",
    "ell_Grek",
    "eng_Latn",
    "est_Latn",
    "eus_Latn",
    "fin_Latn",
    "fra_Latn",
    "fuv_Latn",
    "gaz_Latn",
    "grn_Latn",
    "guj_Gujr",
    "hat_Latn",
    "hau_Latn",
    "heb_Hebr",
    "hin_Deva",
    "hin_Latn",
    "hrv_Latn",
    "hun_Latn",
    "hye_Armn",
    "ibo_Latn",
    "ilo_Latn",
    "ind_Latn",
    "isl_Latn",
    "ita_Latn",
    "jav_Latn",
    "jpn_Jpan",
    "kac_Latn",
    "kan_Knda",
    "kat_Geor",
    "kaz_Cyrl",
    "kea_Latn",
    "khk_Cyrl",
    "khm_Khmr",
    "kin_Latn",
    "kir_Cyrl",
    "kor_Hang",
    "lao_Laoo",
    "lin_Latn",
    "lit_Latn",
    "lug_Latn",
    "luo_Latn",
    "lvs_Latn",
    "mal_Mlym",
    "mar_Deva",
    "mkd_Cyrl",
    "mlt_Latn",
    "mri_Latn",
    "mya_Mymr",
    "nld_Latn",
    "nob_Latn",
    "npi_Deva",
    "npi_Latn",
    "nso_Latn",
    "nya_Latn",
    "ory_Orya",
    "pan_Guru",
    "pbt_Arab",
    "pes_Arab",
    "plt_Latn",
    "pol_Latn",
    "por_Latn",
    "ron_Latn",
    "rus_Cyrl",
    "shn_Mymr",
    "sin_Latn",
    "sin_Sinh",
    "slk_Latn",
    "slv_Latn",
    "sna_Latn",
    "snd_Arab",
    "som_Latn",
    "sot_Latn",
    "spa_Latn",
    "srp_Cyrl",
    "ssw_Latn",
    "sun_Latn",
    "swe_Latn",
    "swh_Latn",
    "tam_Taml",
    "tel_Telu",
    "tgk_Cyrl",
    "tgl_Latn",
    "tha_Thai",
    "tir_Ethi",
    "tsn_Latn",
    "tso_Latn",
    "tur_Latn",
    "ukr_Cyrl",
    "urd_Arab",
    "urd_Latn",
    "uzn_Latn",
    "vie_Latn",
    "war_Latn",
    "wol_Latn",
    "xho_Latn",
    "yor_Latn",
    "zho_Hans",
    "zho_Hant",
    "zsm_Latn",
    "zul_Latn",
]


def get_lang_pairs() -> dict[str, list[str]]:
    # add pairs with same langauge as the source and target
    # add pairs with english as source or target
    lang_pairs = {}
    for x in _LANGUAGES:
        pair = f"{x}-{x}"
        lang_pairs[pair] = [x.replace("_", "-"), x.replace("_", "-")]

        if x != "eng_Latn":
            pair = f"{x}-eng_Latn"
            lang_pairs[pair] = [x.replace("_", "-"), "eng-Latn"]
            pair = f"eng_Latn-{x}"
            lang_pairs[pair] = ["eng-Latn", x.replace("_", "-")]

    # add pairs for languages with a base script and a Latn script
    lang_base_scripts = [
        "arb_Arab",
        "ben_Beng",
        "hin_Deva",
        "npi_Deva",
        "sin_Sinh",
        "urd_Arab",
    ]
    for lang_base_script in lang_base_scripts:
        lang = lang_base_script.split("_")[0]
        lang_latn_script = f"{lang}_Latn"
        pair = f"{lang_base_script}-{lang_latn_script}"
        lang_pairs[pair] = [
            lang_base_script.replace("_", "-"),
            lang_latn_script.replace("_", "-"),
        ]
        pair = f"{lang_latn_script}-{lang_base_script}"
        lang_pairs[pair] = [
            lang_latn_script.replace("_", "-"),
            lang_base_script.replace("_", "-"),
        ]

    return lang_pairs


_LANGUAGES_MAPPING = get_lang_pairs()


class BelebeleRetrieval(MultilingualTask, AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="BelebeleRetrieval",
        dataset={
            "path": "facebook/belebele",
            "revision": "75b399394a9803252cfec289d103de462763db7c",
        },
        description=(
            "Belebele is a multiple-choice machine reading comprehension (MRC) dataset spanning 122 language variants "
            "(including 115 distinct languages and their scripts)"
        ),
        type="Retrieval",
        category="s2p",
        eval_splits=[_EVAL_SPLIT],
        eval_langs=_LANGUAGES_MAPPING,
        reference="https://arxiv.org/abs/2308.16884",
        main_score="ndcg_at_10",
        license="CC-BY-SA-4.0",
        domains=["Web", "News"],
        text_creation="created",
        n_samples={_EVAL_SPLIT: 103500},  # number of languages * 900
        date=("2023-08-31", "2023-08-31"),
        form=["written"],
        task_subtypes=["Question answering"],
        socioeconomic_status="mixed",
        annotations_creators="expert-annotated",
        dialect=[],
        avg_character_length={
            "test": {
                "acm_Arab-acm_Arab": {
                    "average_document_length": 416.4733606557377,
                    "average_query_length": 55.84,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "acm_Arab-eng_Latn": {
                    "average_document_length": 416.4733606557377,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-acm_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 55.84,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "afr_Latn-afr_Latn": {
                    "average_document_length": 503.6659836065574,
                    "average_query_length": 78.04555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "afr_Latn-eng_Latn": {
                    "average_document_length": 503.6659836065574,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-afr_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.04555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "als_Latn-als_Latn": {
                    "average_document_length": 534.016393442623,
                    "average_query_length": 76.13555555555556,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "als_Latn-eng_Latn": {
                    "average_document_length": 534.016393442623,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-als_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 76.13555555555556,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "amh_Ethi-amh_Ethi": {
                    "average_document_length": 319.8688524590164,
                    "average_query_length": 49.16111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "amh_Ethi-eng_Latn": {
                    "average_document_length": 319.8688524590164,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-amh_Ethi": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 49.16111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "apc_Arab-apc_Arab": {
                    "average_document_length": 393.0553278688525,
                    "average_query_length": 55.85777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "apc_Arab-eng_Latn": {
                    "average_document_length": 393.0553278688525,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-apc_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 55.85777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arb_Arab-arb_Arab": {
                    "average_document_length": 421.96311475409834,
                    "average_query_length": 58.55,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arb_Arab-eng_Latn": {
                    "average_document_length": 421.96311475409834,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-arb_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 58.55,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arb_Latn-arb_Latn": {
                    "average_document_length": 555.6188524590164,
                    "average_query_length": 67.02444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arb_Latn-eng_Latn": {
                    "average_document_length": 555.6188524590164,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-arb_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 67.02444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ars_Arab-ars_Arab": {
                    "average_document_length": 422.5553278688525,
                    "average_query_length": 56.43222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ars_Arab-eng_Latn": {
                    "average_document_length": 422.5553278688525,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ars_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 56.43222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ary_Arab-ary_Arab": {
                    "average_document_length": 411.1475409836066,
                    "average_query_length": 66.01893095768374,
                    "num_documents": 488,
                    "num_queries": 898,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ary_Arab-eng_Latn": {
                    "average_document_length": 411.1475409836066,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ary_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 66.01893095768374,
                    "num_documents": 488,
                    "num_queries": 898,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arz_Arab-arz_Arab": {
                    "average_document_length": 412.05122950819674,
                    "average_query_length": 57.14111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arz_Arab-eng_Latn": {
                    "average_document_length": 412.05122950819674,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-arz_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 57.14111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "asm_Beng-asm_Beng": {
                    "average_document_length": 458.5983606557377,
                    "average_query_length": 68.26,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "asm_Beng-eng_Latn": {
                    "average_document_length": 458.5983606557377,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-asm_Beng": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.26,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "azj_Latn-azj_Latn": {
                    "average_document_length": 519.6127049180328,
                    "average_query_length": 73.51222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "azj_Latn-eng_Latn": {
                    "average_document_length": 519.6127049180328,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-azj_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 73.51222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "bam_Latn-bam_Latn": {
                    "average_document_length": 457.3114754098361,
                    "average_query_length": 72.34222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "bam_Latn-eng_Latn": {
                    "average_document_length": 457.3114754098361,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-bam_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.34222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ben_Beng-ben_Beng": {
                    "average_document_length": 467.7745901639344,
                    "average_query_length": 69.48444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ben_Beng-eng_Latn": {
                    "average_document_length": 467.7745901639344,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ben_Beng": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 69.48444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ben_Latn-ben_Latn": {
                    "average_document_length": 522.8934426229508,
                    "average_query_length": 74.78777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ben_Latn-eng_Latn": {
                    "average_document_length": 522.8934426229508,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ben_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.78777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "bod_Tibt-bod_Tibt": {
                    "average_document_length": 533.3872950819672,
                    "average_query_length": 86.90222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "bod_Tibt-eng_Latn": {
                    "average_document_length": 533.3872950819672,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-bod_Tibt": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 86.90222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "bul_Cyrl-bul_Cyrl": {
                    "average_document_length": 496.97131147540983,
                    "average_query_length": 72.89,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "bul_Cyrl-eng_Latn": {
                    "average_document_length": 496.97131147540983,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-bul_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.89,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "cat_Latn-cat_Latn": {
                    "average_document_length": 525.4467213114754,
                    "average_query_length": 75.40666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "cat_Latn-eng_Latn": {
                    "average_document_length": 525.4467213114754,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-cat_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.40666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ceb_Latn-ceb_Latn": {
                    "average_document_length": 570.8483606557377,
                    "average_query_length": 81.19666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ceb_Latn-eng_Latn": {
                    "average_document_length": 570.8483606557377,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ceb_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 81.19666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ces_Latn-ces_Latn": {
                    "average_document_length": 461.0061475409836,
                    "average_query_length": 67.73333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ces_Latn-eng_Latn": {
                    "average_document_length": 461.0061475409836,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ces_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 67.73333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ckb_Arab-ckb_Arab": {
                    "average_document_length": 462.98770491803276,
                    "average_query_length": 71.04555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ckb_Arab-eng_Latn": {
                    "average_document_length": 462.98770491803276,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ckb_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 71.04555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "dan_Latn-dan_Latn": {
                    "average_document_length": 489.4856557377049,
                    "average_query_length": 72.96888888888888,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "dan_Latn-eng_Latn": {
                    "average_document_length": 489.4856557377049,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-dan_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.96888888888888,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "deu_Latn-deu_Latn": {
                    "average_document_length": 555.1659836065573,
                    "average_query_length": 75.32444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "deu_Latn-eng_Latn": {
                    "average_document_length": 555.1659836065573,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-deu_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.32444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ell_Grek-ell_Grek": {
                    "average_document_length": 568.3872950819672,
                    "average_query_length": 86.92666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ell_Grek-eng_Latn": {
                    "average_document_length": 568.3872950819672,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ell_Grek": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 86.92666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-eng_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "est_Latn-est_Latn": {
                    "average_document_length": 467.1475409836066,
                    "average_query_length": 67.55888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "est_Latn-eng_Latn": {
                    "average_document_length": 467.1475409836066,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-est_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 67.55888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eus_Latn-eus_Latn": {
                    "average_document_length": 506.19262295081967,
                    "average_query_length": 74.44777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eus_Latn-eng_Latn": {
                    "average_document_length": 506.19262295081967,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-eus_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.44777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "fin_Latn-fin_Latn": {
                    "average_document_length": 507.5,
                    "average_query_length": 72.50888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "fin_Latn-eng_Latn": {
                    "average_document_length": 507.5,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-fin_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.50888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "fra_Latn-fra_Latn": {
                    "average_document_length": 564.8401639344262,
                    "average_query_length": 90.54222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "fra_Latn-eng_Latn": {
                    "average_document_length": 564.8401639344262,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-fra_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 90.54222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "fuv_Latn-fuv_Latn": {
                    "average_document_length": 443.4733606557377,
                    "average_query_length": 58.42111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "fuv_Latn-eng_Latn": {
                    "average_document_length": 443.4733606557377,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-fuv_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 58.42111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "gaz_Latn-gaz_Latn": {
                    "average_document_length": 563.5389344262295,
                    "average_query_length": 85.93222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "gaz_Latn-eng_Latn": {
                    "average_document_length": 563.5389344262295,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-gaz_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 85.93222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "grn_Latn-grn_Latn": {
                    "average_document_length": 480.3299180327869,
                    "average_query_length": 75.10666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "grn_Latn-eng_Latn": {
                    "average_document_length": 480.3299180327869,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-grn_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.10666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "guj_Gujr-guj_Gujr": {
                    "average_document_length": 458.1885245901639,
                    "average_query_length": 62.25666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "guj_Gujr-eng_Latn": {
                    "average_document_length": 458.1885245901639,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-guj_Gujr": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 62.25666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hat_Latn-hat_Latn": {
                    "average_document_length": 438.6700819672131,
                    "average_query_length": 70.64666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hat_Latn-eng_Latn": {
                    "average_document_length": 438.6700819672131,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-hat_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 70.64666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hau_Latn-hau_Latn": {
                    "average_document_length": 507.24590163934425,
                    "average_query_length": 85.8488888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hau_Latn-eng_Latn": {
                    "average_document_length": 507.24590163934425,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-hau_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 85.8488888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "heb_Hebr-heb_Hebr": {
                    "average_document_length": 371.36270491803276,
                    "average_query_length": 55.135555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "heb_Hebr-eng_Latn": {
                    "average_document_length": 371.36270491803276,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-heb_Hebr": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 55.135555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hin_Deva-hin_Deva": {
                    "average_document_length": 473.55737704918033,
                    "average_query_length": 72.61777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hin_Deva-eng_Latn": {
                    "average_document_length": 473.55737704918033,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-hin_Deva": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.61777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hin_Latn-hin_Latn": {
                    "average_document_length": 541.7315573770492,
                    "average_query_length": 74.81222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hin_Latn-eng_Latn": {
                    "average_document_length": 541.7315573770492,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-hin_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.81222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hrv_Latn-hrv_Latn": {
                    "average_document_length": 469.202868852459,
                    "average_query_length": 68.83555555555556,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hrv_Latn-eng_Latn": {
                    "average_document_length": 469.202868852459,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-hrv_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.83555555555556,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hun_Latn-hun_Latn": {
                    "average_document_length": 501.1946721311475,
                    "average_query_length": 74.40555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hun_Latn-eng_Latn": {
                    "average_document_length": 501.1946721311475,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-hun_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.40555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hye_Armn-hye_Armn": {
                    "average_document_length": 527.5102459016393,
                    "average_query_length": 75.42555555555556,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hye_Armn-eng_Latn": {
                    "average_document_length": 527.5102459016393,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-hye_Armn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.42555555555556,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ibo_Latn-ibo_Latn": {
                    "average_document_length": 482.3483606557377,
                    "average_query_length": 72.51501668520578,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "ibo_Latn-eng_Latn": {
                    "average_document_length": 482.3483606557377,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ibo_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.51501668520578,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "ilo_Latn-ilo_Latn": {
                    "average_document_length": 574.6987704918033,
                    "average_query_length": 85.7611111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ilo_Latn-eng_Latn": {
                    "average_document_length": 574.6987704918033,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ilo_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 85.7611111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ind_Latn-ind_Latn": {
                    "average_document_length": 516.0573770491803,
                    "average_query_length": 82.10555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ind_Latn-eng_Latn": {
                    "average_document_length": 516.0573770491803,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ind_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 82.10555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "isl_Latn-isl_Latn": {
                    "average_document_length": 470.73975409836066,
                    "average_query_length": 77.27333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "isl_Latn-eng_Latn": {
                    "average_document_length": 470.73975409836066,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-isl_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 77.27333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ita_Latn-ita_Latn": {
                    "average_document_length": 560.9344262295082,
                    "average_query_length": 83.49777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ita_Latn-eng_Latn": {
                    "average_document_length": 560.9344262295082,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ita_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 83.49777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "jav_Latn-jav_Latn": {
                    "average_document_length": 494.1803278688525,
                    "average_query_length": 78.60666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "jav_Latn-eng_Latn": {
                    "average_document_length": 494.1803278688525,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-jav_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.60666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "jpn_Jpan-jpn_Jpan": {
                    "average_document_length": 207.74795081967213,
                    "average_query_length": 35.79,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "jpn_Jpan-eng_Latn": {
                    "average_document_length": 207.74795081967213,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-jpn_Jpan": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 35.79,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kac_Latn-kac_Latn": {
                    "average_document_length": 605.2889344262295,
                    "average_query_length": 98.64182424916574,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kac_Latn-eng_Latn": {
                    "average_document_length": 605.2889344262295,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kac_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 98.64182424916574,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kan_Knda-kan_Knda": {
                    "average_document_length": 498.9077868852459,
                    "average_query_length": 72.13666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kan_Knda-eng_Latn": {
                    "average_document_length": 498.9077868852459,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kan_Knda": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.13666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kat_Geor-kat_Geor": {
                    "average_document_length": 521.7766393442623,
                    "average_query_length": 74.81444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kat_Geor-eng_Latn": {
                    "average_document_length": 521.7766393442623,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kat_Geor": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.81444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kaz_Cyrl-kaz_Cyrl": {
                    "average_document_length": 488.2110655737705,
                    "average_query_length": 70.75666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kaz_Cyrl-eng_Latn": {
                    "average_document_length": 488.2110655737705,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kaz_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 70.75666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kea_Latn-kea_Latn": {
                    "average_document_length": 471.5594262295082,
                    "average_query_length": 75.94111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kea_Latn-eng_Latn": {
                    "average_document_length": 471.5594262295082,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kea_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.94111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "khk_Cyrl-khk_Cyrl": {
                    "average_document_length": 496.655737704918,
                    "average_query_length": 73.33444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "khk_Cyrl-eng_Latn": {
                    "average_document_length": 496.655737704918,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-khk_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 73.33444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "khm_Khmr-khm_Khmr": {
                    "average_document_length": 562.4139344262295,
                    "average_query_length": 75.74888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "khm_Khmr-eng_Latn": {
                    "average_document_length": 562.4139344262295,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-khm_Khmr": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.74888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kin_Latn-kin_Latn": {
                    "average_document_length": 529.2520491803278,
                    "average_query_length": 79.89655172413794,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "kin_Latn-eng_Latn": {
                    "average_document_length": 529.2520491803278,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kin_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 79.89655172413794,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "kir_Cyrl-kir_Cyrl": {
                    "average_document_length": 487.80737704918033,
                    "average_query_length": 74.42333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kir_Cyrl-eng_Latn": {
                    "average_document_length": 487.80737704918033,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kir_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.42333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kor_Hang-kor_Hang": {
                    "average_document_length": 241.32991803278688,
                    "average_query_length": 35.257777777777775,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "kor_Hang-eng_Latn": {
                    "average_document_length": 241.32991803278688,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-kor_Hang": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 35.257777777777775,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "lao_Laoo-lao_Laoo": {
                    "average_document_length": 471.6495901639344,
                    "average_query_length": 63.31333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "lao_Laoo-eng_Latn": {
                    "average_document_length": 471.6495901639344,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-lao_Laoo": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 63.31333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "lin_Latn-lin_Latn": {
                    "average_document_length": 512.9016393442623,
                    "average_query_length": 81.56681514476615,
                    "num_documents": 488,
                    "num_queries": 898,
                    "average_relevant_docs_per_query": 1.0022271714922049,
                },
                "lin_Latn-eng_Latn": {
                    "average_document_length": 512.9016393442623,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-lin_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 81.56681514476615,
                    "num_documents": 488,
                    "num_queries": 898,
                    "average_relevant_docs_per_query": 1.0022271714922049,
                },
                "lit_Latn-lit_Latn": {
                    "average_document_length": 474.0553278688525,
                    "average_query_length": 68.69888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "lit_Latn-eng_Latn": {
                    "average_document_length": 474.0553278688525,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-lit_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.69888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "lug_Latn-lug_Latn": {
                    "average_document_length": 485.73975409836066,
                    "average_query_length": 78.52057842046719,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "lug_Latn-eng_Latn": {
                    "average_document_length": 485.73975409836066,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-lug_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.52057842046719,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "luo_Latn-luo_Latn": {
                    "average_document_length": 497.53688524590166,
                    "average_query_length": 73.14333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "luo_Latn-eng_Latn": {
                    "average_document_length": 497.53688524590166,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-luo_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 73.14333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "lvs_Latn-lvs_Latn": {
                    "average_document_length": 487.21311475409834,
                    "average_query_length": 69.97888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "lvs_Latn-eng_Latn": {
                    "average_document_length": 487.21311475409834,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-lvs_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 69.97888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mal_Mlym-mal_Mlym": {
                    "average_document_length": 539.2827868852459,
                    "average_query_length": 80.69222222222223,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mal_Mlym-eng_Latn": {
                    "average_document_length": 539.2827868852459,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-mal_Mlym": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 80.69222222222223,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mar_Deva-mar_Deva": {
                    "average_document_length": 478.67418032786884,
                    "average_query_length": 68.62625139043382,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "mar_Deva-eng_Latn": {
                    "average_document_length": 478.67418032786884,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-mar_Deva": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.62625139043382,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "mkd_Cyrl-mkd_Cyrl": {
                    "average_document_length": 495.77868852459017,
                    "average_query_length": 74.01333333333334,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mkd_Cyrl-eng_Latn": {
                    "average_document_length": 495.77868852459017,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-mkd_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.01333333333334,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mlt_Latn-mlt_Latn": {
                    "average_document_length": 525.8995901639345,
                    "average_query_length": 75.00444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mlt_Latn-eng_Latn": {
                    "average_document_length": 525.8995901639345,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-mlt_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.00444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mri_Latn-mri_Latn": {
                    "average_document_length": 526.0860655737705,
                    "average_query_length": 81.71444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mri_Latn-eng_Latn": {
                    "average_document_length": 526.0860655737705,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-mri_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 81.71444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mya_Mymr-mya_Mymr": {
                    "average_document_length": 590.389344262295,
                    "average_query_length": 89.28333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "mya_Mymr-eng_Latn": {
                    "average_document_length": 590.389344262295,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-mya_Mymr": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 89.28333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nld_Latn-nld_Latn": {
                    "average_document_length": 529.1434426229508,
                    "average_query_length": 75.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nld_Latn-eng_Latn": {
                    "average_document_length": 529.1434426229508,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-nld_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nob_Latn-nob_Latn": {
                    "average_document_length": 479.13729508196724,
                    "average_query_length": 71.04555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nob_Latn-eng_Latn": {
                    "average_document_length": 479.13729508196724,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-nob_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 71.04555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "npi_Deva-npi_Deva": {
                    "average_document_length": 456.9590163934426,
                    "average_query_length": 66.89666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "npi_Deva-eng_Latn": {
                    "average_document_length": 456.9590163934426,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-npi_Deva": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 66.89666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "npi_Latn-npi_Latn": {
                    "average_document_length": 515.9815573770492,
                    "average_query_length": 71.89666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "npi_Latn-eng_Latn": {
                    "average_document_length": 515.9815573770492,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-npi_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 71.89666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nso_Latn-nso_Latn": {
                    "average_document_length": 548.0225409836065,
                    "average_query_length": 86.77444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nso_Latn-eng_Latn": {
                    "average_document_length": 548.0225409836065,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-nso_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 86.77444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nya_Latn-nya_Latn": {
                    "average_document_length": 532.3934426229508,
                    "average_query_length": 90.78777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "nya_Latn-eng_Latn": {
                    "average_document_length": 532.3934426229508,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-nya_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 90.78777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ory_Orya-ory_Orya": {
                    "average_document_length": 487.78483606557376,
                    "average_query_length": 72.95777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ory_Orya-eng_Latn": {
                    "average_document_length": 487.78483606557376,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ory_Orya": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.95777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pan_Guru-pan_Guru": {
                    "average_document_length": 480.2438524590164,
                    "average_query_length": 73.29777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pan_Guru-eng_Latn": {
                    "average_document_length": 480.2438524590164,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-pan_Guru": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 73.29777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pbt_Arab-pbt_Arab": {
                    "average_document_length": 453.3299180327869,
                    "average_query_length": 67.67111111111112,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pbt_Arab-eng_Latn": {
                    "average_document_length": 453.3299180327869,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-pbt_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 67.67111111111112,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pes_Arab-pes_Arab": {
                    "average_document_length": 448.84631147540983,
                    "average_query_length": 64.75111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pes_Arab-eng_Latn": {
                    "average_document_length": 448.84631147540983,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-pes_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 64.75111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "plt_Latn-plt_Latn": {
                    "average_document_length": 581.2745901639345,
                    "average_query_length": 94.99555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "plt_Latn-eng_Latn": {
                    "average_document_length": 581.2745901639345,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-plt_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 94.99555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pol_Latn-pol_Latn": {
                    "average_document_length": 504.0409836065574,
                    "average_query_length": 74.09777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "pol_Latn-eng_Latn": {
                    "average_document_length": 504.0409836065574,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-pol_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.09777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "por_Latn-por_Latn": {
                    "average_document_length": 517.2827868852459,
                    "average_query_length": 78.11666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "por_Latn-eng_Latn": {
                    "average_document_length": 517.2827868852459,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-por_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.11666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ron_Latn-ron_Latn": {
                    "average_document_length": 534.8668032786885,
                    "average_query_length": 78.74222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ron_Latn-eng_Latn": {
                    "average_document_length": 534.8668032786885,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ron_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.74222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "rus_Cyrl-rus_Cyrl": {
                    "average_document_length": 520.1700819672132,
                    "average_query_length": 83.16333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "rus_Cyrl-eng_Latn": {
                    "average_document_length": 520.1700819672132,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-rus_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 83.16333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "shn_Mymr-shn_Mymr": {
                    "average_document_length": 676.172131147541,
                    "average_query_length": 75.90222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "shn_Mymr-eng_Latn": {
                    "average_document_length": 676.172131147541,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-shn_Mymr": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 75.90222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sin_Latn-sin_Latn": {
                    "average_document_length": 590.7889344262295,
                    "average_query_length": 94.46666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sin_Latn-eng_Latn": {
                    "average_document_length": 590.7889344262295,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-sin_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 94.46666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sin_Sinh-sin_Sinh": {
                    "average_document_length": 478.66803278688525,
                    "average_query_length": 69.91777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sin_Sinh-eng_Latn": {
                    "average_document_length": 478.66803278688525,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-sin_Sinh": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 69.91777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "slk_Latn-slk_Latn": {
                    "average_document_length": 476.7766393442623,
                    "average_query_length": 68.5411111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "slk_Latn-eng_Latn": {
                    "average_document_length": 476.7766393442623,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-slk_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.5411111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "slv_Latn-slv_Latn": {
                    "average_document_length": 474.84631147540983,
                    "average_query_length": 68.79888888888888,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "slv_Latn-eng_Latn": {
                    "average_document_length": 474.84631147540983,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-slv_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.79888888888888,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sna_Latn-sna_Latn": {
                    "average_document_length": 532.5860655737705,
                    "average_query_length": 81.30700778642937,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sna_Latn-eng_Latn": {
                    "average_document_length": 532.5860655737705,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-sna_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 81.30700778642937,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0,
                },
                "snd_Arab-snd_Arab": {
                    "average_document_length": 431.48770491803276,
                    "average_query_length": 63.42333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "snd_Arab-eng_Latn": {
                    "average_document_length": 431.48770491803276,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-snd_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 63.42333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "som_Latn-som_Latn": {
                    "average_document_length": 542.0737704918033,
                    "average_query_length": 90.95777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "som_Latn-eng_Latn": {
                    "average_document_length": 542.0737704918033,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-som_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 90.95777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sot_Latn-sot_Latn": {
                    "average_document_length": 573.3258196721312,
                    "average_query_length": 83.13111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sot_Latn-eng_Latn": {
                    "average_document_length": 573.3258196721312,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-sot_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 83.13111111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "spa_Latn-spa_Latn": {
                    "average_document_length": 564.3319672131148,
                    "average_query_length": 82.16,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "spa_Latn-eng_Latn": {
                    "average_document_length": 564.3319672131148,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-spa_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 82.16,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "srp_Cyrl-srp_Cyrl": {
                    "average_document_length": 471.84631147540983,
                    "average_query_length": 67.49833147942158,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "srp_Cyrl-eng_Latn": {
                    "average_document_length": 471.84631147540983,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-srp_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 67.49833147942158,
                    "num_documents": 488,
                    "num_queries": 899,
                    "average_relevant_docs_per_query": 1.0011123470522802,
                },
                "ssw_Latn-ssw_Latn": {
                    "average_document_length": 535.0901639344262,
                    "average_query_length": 81.09777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ssw_Latn-eng_Latn": {
                    "average_document_length": 535.0901639344262,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ssw_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 81.09777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sun_Latn-sun_Latn": {
                    "average_document_length": 495.3032786885246,
                    "average_query_length": 78.16,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sun_Latn-eng_Latn": {
                    "average_document_length": 495.3032786885246,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-sun_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.16,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "swe_Latn-swe_Latn": {
                    "average_document_length": 480.6803278688525,
                    "average_query_length": 68.67666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "swe_Latn-eng_Latn": {
                    "average_document_length": 480.6803278688525,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-swe_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.67666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "swh_Latn-swh_Latn": {
                    "average_document_length": 499.0983606557377,
                    "average_query_length": 80.56,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "swh_Latn-eng_Latn": {
                    "average_document_length": 499.0983606557377,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-swh_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 80.56,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tam_Taml-tam_Taml": {
                    "average_document_length": 555.5286885245902,
                    "average_query_length": 81.12777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tam_Taml-eng_Latn": {
                    "average_document_length": 555.5286885245902,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tam_Taml": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 81.12777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tel_Telu-tel_Telu": {
                    "average_document_length": 481.5245901639344,
                    "average_query_length": 72.18777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tel_Telu-eng_Latn": {
                    "average_document_length": 481.5245901639344,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tel_Telu": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.18777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tgk_Cyrl-tgk_Cyrl": {
                    "average_document_length": 528.516393442623,
                    "average_query_length": 74.28111111111112,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tgk_Cyrl-eng_Latn": {
                    "average_document_length": 528.516393442623,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tgk_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 74.28111111111112,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tgl_Latn-tgl_Latn": {
                    "average_document_length": 597.6270491803278,
                    "average_query_length": 82.34555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tgl_Latn-eng_Latn": {
                    "average_document_length": 597.6270491803278,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tgl_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 82.34555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tha_Thai-tha_Thai": {
                    "average_document_length": 456.1659836065574,
                    "average_query_length": 59.46666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tha_Thai-eng_Latn": {
                    "average_document_length": 456.1659836065574,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tha_Thai": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 59.46666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tir_Ethi-tir_Ethi": {
                    "average_document_length": 327.6967213114754,
                    "average_query_length": 51.99888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tir_Ethi-eng_Latn": {
                    "average_document_length": 327.6967213114754,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tir_Ethi": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 51.99888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tsn_Latn-tsn_Latn": {
                    "average_document_length": 591.7131147540983,
                    "average_query_length": 87.12777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tsn_Latn-eng_Latn": {
                    "average_document_length": 591.7131147540983,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tsn_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 87.12777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tso_Latn-tso_Latn": {
                    "average_document_length": 569.6475409836065,
                    "average_query_length": 91.69444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tso_Latn-eng_Latn": {
                    "average_document_length": 569.6475409836065,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tso_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 91.69444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tur_Latn-tur_Latn": {
                    "average_document_length": 489.0409836065574,
                    "average_query_length": 71.56222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "tur_Latn-eng_Latn": {
                    "average_document_length": 489.0409836065574,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-tur_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 71.56222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ukr_Cyrl-ukr_Cyrl": {
                    "average_document_length": 488.11475409836066,
                    "average_query_length": 72.08222222222223,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ukr_Cyrl-eng_Latn": {
                    "average_document_length": 488.11475409836066,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-ukr_Cyrl": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 72.08222222222223,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "urd_Arab-urd_Arab": {
                    "average_document_length": 470.452868852459,
                    "average_query_length": 70.52666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "urd_Arab-eng_Latn": {
                    "average_document_length": 470.452868852459,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-urd_Arab": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 70.52666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "urd_Latn-urd_Latn": {
                    "average_document_length": 590.5348360655738,
                    "average_query_length": 90.07,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "urd_Latn-eng_Latn": {
                    "average_document_length": 590.5348360655738,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-urd_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 90.07,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "uzn_Latn-uzn_Latn": {
                    "average_document_length": 539.2418032786885,
                    "average_query_length": 77.61333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "uzn_Latn-eng_Latn": {
                    "average_document_length": 539.2418032786885,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-uzn_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 77.61333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "vie_Latn-vie_Latn": {
                    "average_document_length": 499.8360655737705,
                    "average_query_length": 73.05333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "vie_Latn-eng_Latn": {
                    "average_document_length": 499.8360655737705,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-vie_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 73.05333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "war_Latn-war_Latn": {
                    "average_document_length": 592.8688524590164,
                    "average_query_length": 86.07555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "war_Latn-eng_Latn": {
                    "average_document_length": 592.8688524590164,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-war_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 86.07555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "wol_Latn-wol_Latn": {
                    "average_document_length": 456.9795081967213,
                    "average_query_length": 70.60555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "wol_Latn-eng_Latn": {
                    "average_document_length": 456.9795081967213,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-wol_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 70.60555555555555,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "xho_Latn-xho_Latn": {
                    "average_document_length": 505.0655737704918,
                    "average_query_length": 78.50333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "xho_Latn-eng_Latn": {
                    "average_document_length": 505.0655737704918,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-xho_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.50333333333333,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "yor_Latn-yor_Latn": {
                    "average_document_length": 459.5204918032787,
                    "average_query_length": 68.64,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "yor_Latn-eng_Latn": {
                    "average_document_length": 459.5204918032787,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-yor_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 68.64,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zho_Hans-zho_Hans": {
                    "average_document_length": 159.76024590163934,
                    "average_query_length": 21.747777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zho_Hans-eng_Latn": {
                    "average_document_length": 159.76024590163934,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-zho_Hans": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 21.747777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zho_Hant-zho_Hant": {
                    "average_document_length": 149.77254098360655,
                    "average_query_length": 21.07888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zho_Hant-eng_Latn": {
                    "average_document_length": 149.77254098360655,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-zho_Hant": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 21.07888888888889,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zsm_Latn-zsm_Latn": {
                    "average_document_length": 528.9139344262295,
                    "average_query_length": 78.92444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zsm_Latn-eng_Latn": {
                    "average_document_length": 528.9139344262295,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-zsm_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 78.92444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zul_Latn-zul_Latn": {
                    "average_document_length": 532.9713114754098,
                    "average_query_length": 76.0411111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "zul_Latn-eng_Latn": {
                    "average_document_length": 532.9713114754098,
                    "average_query_length": 77.34777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "eng_Latn-zul_Latn": {
                    "average_document_length": 475.51024590163934,
                    "average_query_length": 76.0411111111111,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arb_Arab-arb_Latn": {
                    "average_document_length": 421.96311475409834,
                    "average_query_length": 67.02444444444444,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "arb_Latn-arb_Arab": {
                    "average_document_length": 555.6188524590164,
                    "average_query_length": 58.55,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ben_Beng-ben_Latn": {
                    "average_document_length": 467.7745901639344,
                    "average_query_length": 74.78777777777778,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "ben_Latn-ben_Beng": {
                    "average_document_length": 522.8934426229508,
                    "average_query_length": 69.48444444444445,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hin_Deva-hin_Latn": {
                    "average_document_length": 473.55737704918033,
                    "average_query_length": 74.81222222222222,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "hin_Latn-hin_Deva": {
                    "average_document_length": 541.7315573770492,
                    "average_query_length": 72.61777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "npi_Deva-npi_Latn": {
                    "average_document_length": 456.9590163934426,
                    "average_query_length": 71.89666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "npi_Latn-npi_Deva": {
                    "average_document_length": 515.9815573770492,
                    "average_query_length": 66.89666666666666,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sin_Sinh-sin_Latn": {
                    "average_document_length": 478.66803278688525,
                    "average_query_length": 94.46666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "sin_Latn-sin_Sinh": {
                    "average_document_length": 590.7889344262295,
                    "average_query_length": 69.91777777777777,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "urd_Arab-urd_Latn": {
                    "average_document_length": 470.452868852459,
                    "average_query_length": 90.07,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
                "urd_Latn-urd_Arab": {
                    "average_document_length": 590.5348360655738,
                    "average_query_length": 70.52666666666667,
                    "num_documents": 488,
                    "num_queries": 900,
                    "average_relevant_docs_per_query": 1.0,
                },
            }
        },
        bibtex_citation="""@article{bandarkar2023belebele,
      title={The Belebele Benchmark: a Parallel Reading Comprehension Dataset in 122 Language Variants}, 
      author={Lucas Bandarkar and Davis Liang and Benjamin Muller and Mikel Artetxe and Satya Narayan Shukla and Donald Husa and Naman Goyal and Abhinandan Krishnan and Luke Zettlemoyer and Madian Khabsa},
      year={2023},
      journal={arXiv preprint arXiv:2308.16884}
}""",
    )

    def load_data(self, **kwargs) -> None:
        if self.data_loaded:
            return

        self.dataset = load_dataset(**self.metadata.dataset)

        self.queries = {lang_pair: {_EVAL_SPLIT: {}} for lang_pair in self.hf_subsets}
        self.corpus = {lang_pair: {_EVAL_SPLIT: {}} for lang_pair in self.hf_subsets}
        self.relevant_docs = {
            lang_pair: {_EVAL_SPLIT: {}} for lang_pair in self.hf_subsets
        }

        for lang_pair in self.hf_subsets:
            languages = self.metadata.eval_langs[lang_pair]
            lang_corpus, lang_question = (
                languages[0].replace("-", "_"),
                languages[1].replace("-", "_"),
            )
            ds_corpus = self.dataset[lang_corpus]
            ds_question = self.dataset[lang_question]

            question_ids = {
                question: _id
                for _id, question in enumerate(set(ds_question["question"]))
            }

            link_to_context_id = {}
            context_idx = 0
            for row in ds_corpus:
                if row["link"] not in link_to_context_id:
                    context_id = f"C{context_idx}"
                    link_to_context_id[row["link"]] = context_id
                    self.corpus[lang_pair][_EVAL_SPLIT][context_id] = {
                        "title": "",
                        "text": row["flores_passage"],
                    }
                    context_idx = context_idx + 1

            for row in ds_question:
                query = row["question"]
                query_id = f"Q{question_ids[query]}"
                self.queries[lang_pair][_EVAL_SPLIT][query_id] = query

                context_link = row["link"]
                context_id = link_to_context_id[context_link]
                if query_id not in self.relevant_docs[lang_pair][_EVAL_SPLIT]:
                    self.relevant_docs[lang_pair][_EVAL_SPLIT][query_id] = {}
                self.relevant_docs[lang_pair][_EVAL_SPLIT][query_id][context_id] = 1

        self.data_loaded = True



from __future__ import annotations

import datasets

from mteb.abstasks.AbsTaskRetrieval import AbsTaskRetrieval
from mteb.abstasks.TaskMetadata import TaskMetadata

_EVAL_SPLIT = "test"


class NLPJournalTitleIntroRetrieval(AbsTaskRetrieval):
    metadata = TaskMetadata(
        name="NLPJournalTitleIntroRetrieval",
        description="This dataset was created from the Japanese NLP Journal LaTeX Corpus. The titles, abstracts and introductions of the academic papers were shuffled. The goal is to find the corresponding introduction with the given title.",
        reference="https://github.com/sbintuitions/JMTEB",
        dataset={
            "path": "sbintuitions/JMTEB",
            "revision": "e4af6c73182bebb41d94cb336846e5a452454ea7",
            "trust_remote_code": True,
        },
        type="Retrieval",
        category="s2s",
        eval_splits=[_EVAL_SPLIT],
        eval_langs=["jpn-Jpan"],
        main_score="ndcg_at_10",
        date=("2000-01-01", "2023-12-31"),
        form=["written"],
        domains=["Academic"],
        task_subtypes=[],
        license="cc-by-4.0",
        socioeconomic_status="high",
        annotations_creators="derived",
        dialect=[],
        text_creation="found",
        bibtex_citation="",
        n_samples={_EVAL_SPLIT: 404},
        avg_character_length={
            "test": {
                "average_document_length": 2052.8611111111113,
                "average_query_length": 27.60891089108911,
                "num_documents": 504,
                "num_queries": 404,
                "average_relevant_docs_per_query": 1.0,
            }
        },
    )

    def load_data(self, **kwargs):
        if self.data_loaded:
            return

        query_list = datasets.load_dataset(
            name="nlp_journal_title_intro-query",
            split=_EVAL_SPLIT,
            **self.metadata_dict["dataset"],
        )

        queries = {}
        qrels = {}
        for row_id, row in enumerate(query_list):
            queries[str(row_id)] = row["query"]
            qrels[str(row_id)] = {str(row["relevant_docs"]): 1}

        corpus_list = datasets.load_dataset(
            name="nlp_journal_title_intro-corpus",
            split="corpus",
            **self.metadata_dict["dataset"],
        )

        corpus = {str(row["docid"]): {"text": row["text"]} for row in corpus_list}

        self.corpus = {_EVAL_SPLIT: corpus}
        self.queries = {_EVAL_SPLIT: queries}
        self.relevant_docs = {_EVAL_SPLIT: qrels}

        self.data_loaded = True



from __future__ import annotations

from mteb.abstasks import AbsTaskClassification
from mteb.abstasks.TaskMetadata import TaskMetadata

N_SAMPLES = 2048


class TweetEmotionClassification(AbsTaskClassification):
    metadata = TaskMetadata(
        name="TweetEmotionClassification",
        dataset={
            "path": "emotone-ar-cicling2017/emotone_ar",
            "revision": "0ded8ff72cc68cbb7bb5c01b0a9157982b73ddaf",
            "trust_remote_code": True,
        },
        description="A dataset of 10,000 tweets that was created with the aim of covering the most frequently used emotion categories in Arabic tweets.",
        reference="https://link.springer.com/chapter/10.1007/978-3-319-77116-8_8",
        type="Classification",
        category="s2s",
        eval_splits=["train"],
        eval_langs=["ara-Arab"],
        main_score="accuracy",
        date=("2014-01-01", "2016-08-31"),
        form=["written"],
        domains=["Social"],
        task_subtypes=["Sentiment/Hate speech"],
        license="Not specified",
        socioeconomic_status="mixed",
        annotations_creators="human-annotated",
        dialect=["ara-arab-EG", "ara-arab-LB", "ara-arab-JO", "ara-arab-SA"],
        text_creation="found",
        bibtex_citation="""
@inproceedings{al2018emotional,
  title={Emotional tone detection in arabic tweets},
  author={Al-Khatib, Amr and El-Beltagy, Samhaa R},
  booktitle={Computational Linguistics and Intelligent Text Processing: 18th International Conference, CICLing 2017, Budapest, Hungary, April 17--23, 2017, Revised Selected Papers, Part II 18},
  pages={105--114},
  year={2018},
  organization={Springer}
}
""",
        n_samples={"train": N_SAMPLES},
        avg_character_length={"train": 78.8},
    )

    def dataset_transform(self):
        self.dataset = self.dataset.rename_column("tweet", "text")
        self.dataset = self.stratified_subsampling(
            self.dataset, seed=self.seed, splits=["train"]
        )



from __future__ import annotations

import logging

from ..evaluation.evaluators import STSEvaluator
from ..MTEBResults import ScoresDict
from .AbsTask import AbsTask

logger = logging.getLogger(__name__)


class AbsTaskSTS(AbsTask):
    """Abstract class for STS experiments.

    self.load_data() must generate a huggingface dataset with a split matching self.metadata_dict["eval_splits"], and assign it to self.dataset. It must contain the following columns::
        sentence1: str
        sentence2: str
        score: float
    """

    def __init__(self, **kwargs):
        super().__init__(**kwargs)

    @property
    def min_score(self) -> int:
        return self.metadata_dict["min_score"]

    @property
    def max_score(self) -> int:
        return self.metadata_dict["max_score"]

    def _evaluate_subset(self, model, data_split, **kwargs) -> ScoresDict:
        def normalize(x):
            return (x - self.min_score) / (self.max_score - self.min_score)

        normalized_scores = list(map(normalize, data_split["score"]))
        evaluator = STSEvaluator(
            data_split["sentence1"],
            data_split["sentence2"],
            normalized_scores,
            task_name=self.metadata.name,
            **kwargs,
        )
        scores = evaluator(model)

        self._add_main_score(scores)
        return scores

    def _add_main_score(self, scores: ScoresDict) -> None:
        scores["main_score"] = scores[self.metadata.main_score]



from __future__ import annotations

from mteb.abstasks.TaskMetadata import TaskMetadata

from ....abstasks.AbsTaskPairClassification import AbsTaskPairClassification


class SickePLPC(AbsTaskPairClassification):
    metadata = TaskMetadata(
        name="SICK-E-PL",
        dataset={
            "path": "PL-MTEB/sicke-pl-pairclassification",
            "revision": "71bba34b0ece6c56dfcf46d9758a27f7a90f17e9",
        },
        description="Polish version of SICK dataset for textual entailment.",
        reference="https://aclanthology.org/2020.lrec-1.207",
        category="s2s",
        type="PairClassification",
        eval_splits=["test"],
        eval_langs=["pol-Latn"],
        main_score="ap",
        date=None,
        form=None,
        domains=None,
        task_subtypes=None,
        license=None,
        socioeconomic_status=None,
        annotations_creators=None,
        dialect=None,
        text_creation=None,
        bibtex_citation="""@inproceedings{dadas-etal-2020-evaluation,
            title = "Evaluation of Sentence Representations in {P}olish",
            author = "Dadas, Slawomir  and
            Pere{\l}kiewicz, Micha{\l}  and
            Po{\'s}wiata, Rafa{\l}",
            editor = "Calzolari, Nicoletta  and
            B{\'e}chet, Fr{\'e}d{\'e}ric  and
            Blache, Philippe  and
            Choukri, Khalid  and
            Cieri, Christopher  and
            Declerck, Thierry  and
            Goggi, Sara  and
            Isahara, Hitoshi  and
            Maegaard, Bente  and
            Mariani, Joseph  and
            Mazo, H{\'e}l{\`e}ne  and
            Moreno, Asuncion  and
            Odijk, Jan  and
            Piperidis, Stelios",
            booktitle = "Proceedings of the Twelfth Language Resources and Evaluation Conference",
            month = may,
            year = "2020",
            address = "Marseille, France",
            publisher = "European Language Resources Association",
            url = "https://aclanthology.org/2020.lrec-1.207",
            pages = "1674--1680",
            abstract = "Methods for learning sentence representations have been actively developed in recent years. However, the lack of pre-trained models and datasets annotated at the sentence level has been a problem for low-resource languages such as Polish which led to less interest in applying these methods to language-specific tasks. In this study, we introduce two new Polish datasets for evaluating sentence embeddings and provide a comprehensive evaluation of eight sentence representation methods including Polish and multilingual models. We consider classic word embedding models, recently developed contextual embeddings and multilingual sentence encoders, showing strengths and weaknesses of specific approaches. We also examine different methods of aggregating word vectors into a single sentence vector.",
            language = "English",
            ISBN = "979-10-95546-34-4",
        }""",
        n_samples=None,
        avg_character_length=None,
    )

    def dataset_transform(self):
        self.dataset = self.dataset.rename_column("sent1", "sentence1")
        self.dataset = self.dataset.rename_column("sent2", "sentence2")


class PpcPC(AbsTaskPairClassification):
    metadata = TaskMetadata(
        name="PpcPC",
        dataset={
            "path": "PL-MTEB/ppc-pairclassification",
            "revision": "2c7d2df57801a591f6b1e3aaf042e7a04ec7d9f2",
        },
        description="Polish Paraphrase Corpus",
        reference="https://arxiv.org/pdf/2207.12759.pdf",
        category="s2s",
        type="PairClassification",
        eval_splits=["test"],
        eval_langs=["pol-Latn"],
        main_score="ap",
        date=None,
        form=None,
        domains=None,
        task_subtypes=None,
        license=None,
        socioeconomic_status=None,
        annotations_creators=None,
        dialect=None,
        text_creation=None,
        bibtex_citation="""@misc{dadas2022training,
      title={Training Effective Neural Sentence Encoders from Automatically Mined Paraphrases}, 
      author={Sławomir Dadas},
      year={2022},
      eprint={2207.12759},
      archivePrefix={arXiv},
      primaryClass={cs.CL}
}""",
        n_samples=None,
        avg_character_length=None,
    )

    def dataset_transform(self):
        self.dataset = self.dataset.rename_column("sent1", "sentence1")
        self.dataset = self.dataset.rename_column("sent2", "sentence2")


class CdscePC(AbsTaskPairClassification):
    metadata = TaskMetadata(
        name="CDSC-E",
        dataset={
            "path": "PL-MTEB/cdsce-pairclassification",
            "revision": "0a3d4aa409b22f80eb22cbf59b492637637b536d",
        },
        description="Compositional Distributional Semantics Corpus for textual entailment.",
        reference="https://aclanthology.org/P17-1073.pdf",
        category="s2s",
        type="PairClassification",
        eval_splits=["test"],
        eval_langs=["pol-Latn"],
        main_score="ap",
        date=None,
        form=None,
        domains=None,
        task_subtypes=None,
        license=None,
        socioeconomic_status=None,
        annotations_creators=None,
        dialect=None,
        text_creation=None,
        bibtex_citation="""@inproceedings{wroblewska-krasnowska-kieras-2017-polish,
            title = "{P}olish evaluation dataset for compositional distributional semantics models",
            author = "Wr{\'o}blewska, Alina  and
            Krasnowska-Kiera{\'s}, Katarzyna",
            editor = "Barzilay, Regina  and
            Kan, Min-Yen",
            booktitle = "Proceedings of the 55th Annual Meeting of the Association for Computational Linguistics (Volume 1: Long Papers)",
            month = jul,
            year = "2017",
            address = "Vancouver, Canada",
            publisher = "Association for Computational Linguistics",
            url = "https://aclanthology.org/P17-1073",
            doi = "10.18653/v1/P17-1073",
            pages = "784--792",
            abstract = "The paper presents a procedure of building an evaluation dataset. for the validation of compositional distributional semantics models estimated for languages other than English. The procedure generally builds on steps designed to assemble the SICK corpus, which contains pairs of English sentences annotated for semantic relatedness and entailment, because we aim at building a comparable dataset. However, the implementation of particular building steps significantly differs from the original SICK design assumptions, which is caused by both lack of necessary extraneous resources for an investigated language and the need for language-specific transformation rules. The designed procedure is verified on Polish, a fusional language with a relatively free word order, and contributes to building a Polish evaluation dataset. The resource consists of 10K sentence pairs which are human-annotated for semantic relatedness and entailment. The dataset may be used for the evaluation of compositional distributional semantics models of Polish.",
        }""",
        n_samples=None,
        avg_character_length=None,
    )

    def dataset_transform(self):
        self.dataset = self.dataset.rename_column("sent1", "sentence1")
        self.dataset = self.dataset.rename_column("sent2", "sentence2")


class PscPC(AbsTaskPairClassification):
    metadata = TaskMetadata(
        name="PSC",
        dataset={
            "path": "PL-MTEB/psc-pairclassification",
            "revision": "d05a294af9e1d3ff2bfb6b714e08a24a6cabc669",
        },
        description="Polish Summaries Corpus",
        reference="http://www.lrec-conf.org/proceedings/lrec2014/pdf/1211_Paper.pdf",
        category="s2s",
        type="PairClassification",
        eval_splits=["test"],
        eval_langs=["pol-Latn"],
        main_score="ap",
        date=None,
        form=None,
        domains=None,
        task_subtypes=None,
        license=None,
        socioeconomic_status=None,
        annotations_creators=None,
        dialect=None,
        text_creation=None,
        bibtex_citation="""@inproceedings{ogrodniczuk-kopec-2014-polish,
            title = "The {P}olish Summaries Corpus",
            author = "Ogrodniczuk, Maciej  and
            Kope{\'c}, Mateusz",
            editor = "Calzolari, Nicoletta  and
            Choukri, Khalid  and
            Declerck, Thierry  and
            Loftsson, Hrafn  and
            Maegaard, Bente  and
            Mariani, Joseph  and
            Moreno, Asuncion  and
            Odijk, Jan  and
            Piperidis, Stelios",
            booktitle = "Proceedings of the Ninth International Conference on Language Resources and Evaluation ({LREC}'14)",
            month = may,
            year = "2014",
            address = "Reykjavik, Iceland",
            publisher = "European Language Resources Association (ELRA)",
            url = "http://www.lrec-conf.org/proceedings/lrec2014/pdf/1211_Paper.pdf",
            pages = "3712--3715",
            abstract = "This article presents the Polish Summaries Corpus, a new resource created to support the development and evaluation of the tools for automated single-document summarization of Polish. The Corpus contains a large number of manual summaries of news articles, with many independently created summaries for a single text. Such approach is supposed to overcome the annotator bias, which is often described as a problem during the evaluation of the summarization algorithms against a single gold standard. There are several summarizers developed specifically for Polish language, but their in-depth evaluation and comparison was impossible without a large, manually created corpus. We present in detail the process of text selection, annotation process and the contents of the corpus, which includes both abstract free-word summaries, as well as extraction-based summaries created by selecting text spans from the original document. Finally, we describe how that resource could be used not only for the evaluation of the existing summarization tools, but also for studies on the human summarization process in Polish language.",
        }""",
        n_samples=None,
        avg_character_length=None,
    )

    def dataset_transform(self):
        self.dataset = self.dataset.rename_column("sent1", "sentence1")
        self.dataset = self.dataset.rename_column("sent2", "sentence2")
